import { Box, makeStyles, Theme, useMediaQuery } from '@material-ui/core';
import React from 'react';
import DrawerMenu from '../components/DrawerMenu';
import Footer from '../components/Footer';
import Header from '../components/Header';
import MobileHeader from '../components/MobileHeader';
import { useToggle } from '../hooks/useToggle';

const useStyles = makeStyles((theme) => ({
  root: {
    display: 'flex',
    flexDirection: 'column',
    minHeight: '100vh',
    background: theme.palette.background.default,
  },
}));

const Page: React.FC = ({ children }) => {
  const [openDrawer, { toggleOn, toggleOff }] = useToggle(false);
  const isMobile = useMediaQuery((theme: Theme) => theme.breakpoints.down('xs'));
  const classes = useStyles();

  return (
    <Box className={classes.root}>
      {isMobile ? (
        <MobileHeader onMenuClick={toggleOn} />
      ) : (
        <Header handleLogout={(): void => {}} />
      )}
      {isMobile && (
        <DrawerMenu open={openDrawer} toggleOpen={toggleOff} handleLogout={(): void => {}} />
      )}
      <Box flexGrow={1} flexShrink={0} flexBasis="auto">
        {children}
      </Box>
      <Footer />
    </Box>
  );
};

export default Page;
